summaryrefslogtreecommitdiff
path: root/src/mongo/db/s/collection_sharding_runtime.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/s/collection_sharding_runtime.h')
-rw-r--r--src/mongo/db/s/collection_sharding_runtime.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/mongo/db/s/collection_sharding_runtime.h b/src/mongo/db/s/collection_sharding_runtime.h
index 44e46d0bc4a..786425d8e92 100644
--- a/src/mongo/db/s/collection_sharding_runtime.h
+++ b/src/mongo/db/s/collection_sharding_runtime.h
@@ -229,7 +229,7 @@ public:
/**
* Gets an index version under a lock.
*/
- boost::optional<Timestamp> getIndexVersion(OperationContext* opCtx);
+ boost::optional<CollectionIndexes> getCollectionIndexes(OperationContext* opCtx);
/**
* Gets the index list under a lock.
@@ -241,17 +241,17 @@ public:
*/
void addIndex(OperationContext* opCtx,
const IndexCatalogType& index,
- const Timestamp& indexVersion);
+ const CollectionIndexes& collectionIndexes);
/**
* Removes an index from the shard-role index info under a lock.
*/
void removeIndex(OperationContext* opCtx,
const std::string& name,
- const Timestamp& indexVersion);
+ const CollectionIndexes& collectionIndexes);
/**
* Clears the shard-role index info and set the indexVersion to boost::none.
*/
void clearIndexes(OperationContext* opCtx);
@@ -241,17 +241,17 @@ public:
/**
- * Clears the shard-role index info and set the indexVersion to boost::none.
+ * Clears the shard-role index info and set the collectionIndexes to boost::none.
*/
void clearIndexes(OperationContext* opCtx);